@@ -43,10 +43,10 @@ checks = list()
 # checks.append(CheckChangedFilePaths())
 
 # 检查二进制文件
-# checks.append(CheckBinaryFiles())
+checks.append(CheckBinaryFiles())
 
 # 检查文件后缀名
-# checks.append(CommittedFileExtensionCheck())
+checks.append(CommittedFileExtensionCheck())
 
 # 检查文件大小
 checks.append(CommittedFileSizeCheck())
